@@ -1,9 +1,9 @@
 // Copyright 2019-2022 ChainSafe Systems
 // SPDX-License-Identifier: Apache-2.0, MIT
 
+use fvm_ipld_encoding::tuple::{Deserialize_tuple, Serialize_tuple};
+use fvm_ipld_encoding::Cbor;
 use fvm_shared::address::Address;
-use fvm_shared::encoding::tuple::*;
-use fvm_shared::encoding::Cbor;
 use fvm_shared::MethodNum;
 
 /// Cron actor state which holds entries to call during epoch tick
